# Copyright (c) 2009 Richard Boulton
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
r"""List of HTML entity names.

This is used to warn if these are used as parameter names.  Using them as
parameter names will lead to problems if URLs containing the parameters are
incorrectly escaped.

"""
__docformat__ = "restructuredtext en"

# List of entities, copied from
# http://www.w3.org/TR/REC-html40/sgml/entities.html
entities = set((
               'nbsp',
               'iexcl',
               'cent',
               'pound',
               'curren',
               'yen',
               'brvbar',
               'sect',
               'uml',
               'copy',
               'ordf',
               'laquo',
               'not',
               'shy',
               'reg',
               'macr',
               'deg',
               'plusmn',
               'sup2',
               'sup3',
               'acute',
               'micro',
               'para',
               'middot',
               'cedil',
               'sup1',
               'ordm',
               'raquo',
               'frac14',
               'frac12',
               'frac34',
               'iquest',
               'Agrave',
               'Aacute',
               'Acirc',
               'Atilde',
               'Auml',
               'Aring',
               'AElig',
               'Ccedil',
               'Egrave',
               'Eacute',
               'Ecirc',
               'Euml',
               'Igrave',
               'Iacute',
               'Icirc',
               'Iuml',
               'ETH',
               'Ntilde',
               'Ograve',
               'Oacute',
               'Ocirc',
               'Otilde',
               'Ouml',
               'times',
               'Oslash',
               'Ugrave',
               'Uacute',
               'Ucirc',
               'Uuml',
               'Yacute',
               'THORN',
               'szlig',
               'agrave',
               'aacute',
               'acirc',
               'atilde',
               'auml',
               'aring',
               'aelig',
               'ccedil',
               'egrave',
               'eacute',
               'ecirc',
               'euml',
               'igrave',
               'iacute',
               'icirc',
               'iuml',
               'eth',
               'ntilde',
               'ograve',
               'oacute',
               'ocirc',
               'otilde',
               'ouml',
               'divide',
               'oslash',
               'ugrave',
               'uacute',
               'ucirc',
               'uuml',
               'yacute',
               'thorn',
               'yuml',
               'fnof',
               'Alpha',
               'Beta',
               'Gamma',
               'Delta',
               'Epsilon',
               'Zeta',
               'Eta',
               'Theta',
               'Iota',
               'Kappa',
               'Lambda',
               'Mu',
               'Nu',
               'Xi',
               'Omicron',
               'Pi',
               'Rho',
               'Sigma',
               'Tau',
               'Upsilon',
               'Phi',
               'Chi',
               'Psi',
               'Omega',
               'alpha',
               'beta',
               'gamma',
               'delta',
               'epsilon',
               'zeta',
               'eta',
               'theta',
               'iota',
               'kappa',
               'lambda',
               'mu',
               'nu',
               'xi',
               'omicron',
               'pi',
               'rho',
               'sigmaf',
               'sigma',
               'tau',
               'upsilon',
               'phi',
               'chi',
               'psi',
               'omega',
               'thetasym',
               'upsih',
               'piv',
               'bull',
               'hellip',
               'prime',
               'Prime',
               'oline',
               'frasl',
               'weierp',
               'image',
               'real',
               'trade',
               'alefsym',
               'larr',
               'uarr',
               'rarr',
               'darr',
               'harr',
               'crarr',
               'lArr',
               'uArr',
               'rArr',
               'dArr',
               'hArr',
               'forall',
               'part',
               'exist',
               'empty',
               'nabla',
               'isin',
               'notin',
               'ni',
               'prod',
               'sum',
               'minus',
               'lowast',
               'radic',
               'prop',
               'infin',
               'ang',
               'and',
               'or',
               'cap',
               'cup',
               'int',
               'there4',
               'sim',
               'cong',
               'asymp',
               'ne',
               'equiv',
               'le',
               'ge',
               'sub',
               'sup',
               'nsup',
               'nsub',
               'sube',
               'supe',
               'oplus',
               'otimes',
               'perp',
               'sdot',
               'lceil',
               'rceil',
               'lfloor',
               'rfloor',
               'lang',
               'rang',
               'loz',
               'spades',
               'clubs',
               'hearts',
               'diams',
               'quot',
               'amp',
               'lt',
               'gt',
               'OElig',
               'oelig',
               'Scaron',
               'scaron',
               'Yuml',
               'circ',
               'tilde',
               'ensp',
               'emsp',
               'thinsp',
               'zwnj',
               'zwj',
               'lrm',
               'rlm',
               'ndash',
               'mdash',
               'lsquo',
               'rsquo',
               'sbquo',
               'ldquo',
               'rdquo',
               'bdquo',
               'dagger',
               'Dagger',
               'permil',
               'lsaquo',
               'rsaquo',
               'euro',
))

# vim: set fileencoding=utf-8 :
